@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2013  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2016  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -55,16 +55,19 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_SUUSETSUZOKU "³"
 #define NJD_SET_DIGIT_JOSUUSHI ""
 #define NJD_SET_DIGIT_FUKUSHIKANOU "ǽ"
-#define NJD_SET_DIGIT_HAIHUN1 ""
-#define NJD_SET_DIGIT_HAIHUN2 ""
-#define NJD_SET_DIGIT_HAIHUN3 ""
+#define NJD_SET_DIGIT_HAIHUN1 ""     /* horizontal bar */
+#define NJD_SET_DIGIT_HAIHUN2 ""     /* minus sign */
+#define NJD_SET_DIGIT_HAIHUN3 ""     /* hyphen */
+#define NJD_SET_DIGIT_HAIHUN4 ""     /* em dash */
+#define NJD_SET_DIGIT_HAIHUN5 ""     /* fullwidth hyphen-minus */
 #define NJD_SET_DIGIT_KAKKO1 ""
 #define NJD_SET_DIGIT_KAKKO2 ""
 #define NJD_SET_DIGIT_BANGOU "ֹ"
 #define NJD_SET_DIGIT_TEN1 ""
 #define NJD_SET_DIGIT_TEN2 ""
 #define NJD_SET_DIGIT_TEN_FEATURE ",̾,,,*,*,*,,ƥ,ƥ,0/2,*,-1"
-#define NJD_SET_DIGIT_ZERO ""
+#define NJD_SET_DIGIT_ZERO1 ""
+#define NJD_SET_DIGIT_ZERO2 ""
 #define NJD_SET_DIGIT_ZERO_BEFORE_DP "졼"
 #define NJD_SET_DIGIT_ZERO_AFTER_DP ""
 #define NJD_SET_DIGIT_TWO ""
@@ -79,6 +82,15 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_NICHIKAN ""
 #define NJD_SET_DIGIT_ONE ""
 #define NJD_SET_DIGIT_TSUITACHI ",̾,ǽ,*,*,*,*,,ĥ,ĥ,4/4,*"
+#define NJD_SET_DIGIT_FOUR ""
+#define NJD_SET_DIGIT_TEN ""
+#define NJD_SET_DIGIT_JUYOKKA ",̾,ǽ,*,*,*,*,,奦å,塼å,1/5,*"
+#define NJD_SET_DIGIT_JUYOKKAKAN ",̾,ǽ,*,*,*,*,,奦å,塼å,5/7,*"
+#define NJD_SET_DIGIT_NIJU ",̾,ǽ,*,*,*,*,,˥奦,˥塼,1/3,*"
+#define NJD_SET_DITIT_YOKKA ",̾,ǽ,*,*,*,*,,å,å,0/3,*,0"
+#define NJD_SET_DIGIT_YOKKAKAN ",̾,ǽ,*,*,*,*,,å,å,3/5,*,0"
+#define NJD_SET_DITIT_HATSUKA ",̾,ǽ,*,*,*,*,,ϥĥ,ϥĥ,0/3,*"
+#define NJD_SET_DIGIT_HATSUKAKAN ",̾,ǽ,*,*,*,*,,ϥĥ,ϥĥ,3/5,*"
 
 static const char *njd_set_digit_rule_numeral_list1[] = {
    "", "0", "",
@@ -137,8 +149,8 @@ static const char *njd_set_digit_rule_numeral_list3[] = {
    ",̾,,*,*,*,*,,祦,硼,1/2,C3",
    ",̾,,*,*,*,*,,,,1/2,*",
    "Զ,̾,,*,*,*,*,Զ,,,1/2,*",
-   "ͽ,̾,,*,*,*,*,ͽ,,,1/1,*", /* No character in EUC-JP */
-   ",̾,,*,*,*,*,,祦,祦,1/2,*",
+   "ͽ,̾,,*,*,*,*,ͽ,,,1/1,*", /* none in this charcode */
+   ",̾,,*,*,*,*,,祦,硼,1/2,*",
    ",̾,,*,*,*,*,,,,1/2,*",
    ",̾,,*,*,*,*,,,,1/2,*",
    ",̾,,*,*,*,*,,,,1/2,*",
@@ -158,7 +170,9 @@ static const char *njd_set_digit_rule_numeral_list4[] = {
 };
 
 static const char *njd_set_digit_rule_numeral_list5[] = {
-   "", "ɴ", "", "", "", "", "", "Զ", "ͽ", "", "", "", "", "", "",
+   "", "ɴ", "", "", "", "", "", "Զ",
+   "ͽ", /* none in this charcode */
+   "", "", "", "", "", "",
    "Ϻ", "ε", "ͳ¾", "ԲĻ׵", "̵",
    NULL
 };
@@ -211,9 +225,9 @@ static const char *njd_set_digit_rule_conv_table1b[] = {
 
 static const char *njd_set_digit_rule_numerative_class1c1[] = {
    /* from paper */
-   "", "", "",
+   "",
    /* from dictionary */
-   "", "Ⱦ", "ͷ", "", "",
+   "ͷ", "", "",
    NULL
 };
 
@@ -232,6 +246,8 @@ static const char *njd_set_digit_rule_numerative_class1c2[] = {
 };
 
 static const char *njd_set_digit_rule_conv_table1c2[] = {
+   "", "", "0", "1",
+   "", "", "1", "2",
    "", "", "0", "1",
    NULL, NULL, NULL, NULL
 };
@@ -290,9 +306,9 @@ static const char *njd_set_digit_rule_numerative_class1g[] = {
    "", "", "", "", "", "", "", "", "", "", "", "", "", "",
    "", "", "", "", "", "", "", "", "Ť", "", "", "", "", "", "",
    "", "", "", "", "", "", "", "", "", "", "", "", "ǯ", "",
-   "Ԥ", "ڤ", "", "", "", "", "", "", "", "", "", "ɤ", "ɤ", "ɮ", "ɶ",
+   "Ԥ", "ڤ", "", "", "", "", "", "", "", "", "", "ɤ", "ɥ", "ɮ", "ɶ",
    "ɼ", "", "ʬ", "ʬ", "", "", "", "", "", "", "", "", "", "", "",
-   "ˡ", "Ω",
+   "ˡ", "Ω", "Ƭ",
    NULL
 };
 
@@ -319,6 +335,7 @@ static const char *njd_set_digit_rule_numerative_class1h[] = {
    "ޤ", "Ȥ", "Ȥ", "Ȥ", "Ȥ", "", "", "", "«", "³", "", "",
    "", "î", "ȿ", "", "", "Ļ", "", "Ϥ", "", "ũ", "Ź", "ž", "", "", "",
    "", "", "", "", "", "ʬ", "", "", "", "γ", "", "", "",
+   "ּ",
    NULL
 };
 
@@ -369,7 +386,7 @@ static const char *njd_set_digit_rule_numerative_class1k[] = {
    "", "", "ѡ", "ѡߥ", "ѥ", "ѥå", "ѥå", "ԡԡ",
    "ԥ", "ڡ", "", "ڥ", "ڥ", "ڥ", "ڥˡ", "ڥ˥", "ڥ", "ݥ",
    "", "", "", "ĥ", "ʿ", "ʿ", "ʿ᡼ȥ", "ʿ᡼ȥ",
-   "ʿ᡼ȥ",
+   "ʿ᡼ȥ", "",
    NULL
 };
 
@@ -403,7 +420,7 @@ static const char *njd_set_digit_rule_conv_table2b[] = {
 
 static const char *njd_set_digit_rule_numerative_class2c[] = {
    /* from paper */
-   "", "ɤ", "ɼ", "ɶ", "Ȣ",
+   "", "ɤ", "ɥ", "ɼ", "ɶ", "Ȣ",
    /* from dictionary */
    "Ω", "", "", "",
    NULL
@@ -423,7 +440,7 @@ static const char *njd_set_digit_rule_conv_table2c[] = {
 };
 
 static const char *njd_set_digit_rule_numerative_class2d[] = {
-/* from paper */
+   /* from paper */
    /* "", "", *//* modified */
    NULL
 };
@@ -582,17 +599,18 @@ static const char *njd_set_digit_rule_conv_table4[] = {
 
 static const char *njd_set_digit_rule_conv_table5[] = {
    "", ",̾,ǽ,*,*,*,*,,˥,˥,4/4,*",
-   "", ",̾,ǽ,*,*,*,*,,եĥ,եĥ,3/3,*",
-   "", ",̾,ǽ,*,*,*,*,,ߥå,ߥå,3/3,*",
-   "", ",̾,ǽ,*,*,*,*,,å,å,3/3,*",
-   "", ",̾,ǽ,*,*,*,*,,ĥ,ĥ,3/3,*",
-   "ϻ", "ϻ,̾,ǽ,*,*,*,*,ϻ,।,।,3/3,*",
-   "", ",̾,ǽ,*,*,*,*,,ʥΥ,ʥΥ,3/3,*",
-   "Ȭ", "Ȭ,̾,ǽ,*,*,*,*,Ȭ,襦,襦,3/3,*",
-   "", ",̾,ǽ,*,*,*,*,,Υ,Υ,4/4,*",
-   "", ",̾,ǽ,*,*,*,*,,ȥ,ȡ,3/3,*",
+   "", ",̾,ǽ,*,*,*,*,,եĥ,եĥ,0/3,*",
+   "", ",̾,ǽ,*,*,*,*,,ߥå,ߥå,0/3,*",
+   "", ",̾,ǽ,*,*,*,*,,å,å,0/3,*",
+   "", ",̾,ǽ,*,*,*,*,,ĥ,ĥ,0/3,*",
+   "ϻ", "ϻ,̾,ǽ,*,*,*,*,ϻ,।,।,0/3,*",
+   "", ",̾,ǽ,*,*,*,*,,ʥΥ,ʥΥ,0/3,*",
+   "Ȭ", "Ȭ,̾,ǽ,*,*,*,*,Ȭ,襦,衼,0/3,*",
+   "", ",̾,ǽ,*,*,*,*,,Υ,Υ,0/4,*",
+   "", ",̾,ǽ,*,*,*,*,,ȥ,ȡ,0/3,*",
    NULL, NULL
 };
+
 static const char *njd_set_digit_rule_conv_table6[] = {
    "", ",̾,ǽ,*,*,*,*,,˥,˥,4/6,*",
    "", ",̾,ǽ,*,*,*,*,,եĥ,եĥ,3/5,*",
@@ -601,7 +619,7 @@ static const char *njd_set_digit_rule_conv_table6[] = {
    "", ",̾,ǽ,*,*,*,*,,ĥ,ĥ,3/5,*",
    "ϻ", "ϻ,̾,ǽ,*,*,*,*,ϻ,।,।,3/5,*",
    "", ",̾,ǽ,*,*,*,*,,ʥΥ,ʥΥ,3/5,*",
-   "Ȭ", "Ȭ,̾,ǽ,*,*,*,*,Ȭ,襦,襦,3/5,*",
+   "Ȭ", "Ȭ,̾,ǽ,*,*,*,*,Ȭ,襦,衼,3/5,*",
    "", ",̾,ǽ,*,*,*,*,,Υ,Υ,4/6,*",
    "", ",̾,ǽ,*,*,*,*,,ȥ,ȡ,3/5,*",
    NULL, NULL
