@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2013  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2016  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -55,16 +55,19 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_SUUSETSUZOKU "ڑ"
 #define NJD_SET_DIGIT_JOSUUSHI ""
 #define NJD_SET_DIGIT_FUKUSHIKANOU "\"
-#define NJD_SET_DIGIT_HAIHUN1 "\"
-#define NJD_SET_DIGIT_HAIHUN2 "|"
-#define NJD_SET_DIGIT_HAIHUN3 "]"
+#define NJD_SET_DIGIT_HAIHUN1 "\"     /* horizontal bar */
+#define NJD_SET_DIGIT_HAIHUN2 "|"     /* minus sign */
+#define NJD_SET_DIGIT_HAIHUN3 "]"     /* hyphen */
+#define NJD_SET_DIGIT_HAIHUN4 "\"     /* em dash */
+#define NJD_SET_DIGIT_HAIHUN5 "|"     /* fullwidth hyphen-minus */
 #define NJD_SET_DIGIT_KAKKO1 "i"
 #define NJD_SET_DIGIT_KAKKO2 "j"
 #define NJD_SET_DIGIT_BANGOU "ԍ"
 #define NJD_SET_DIGIT_TEN1 "D"
 #define NJD_SET_DIGIT_TEN2 "E"
 #define NJD_SET_DIGIT_TEN_FEATURE "D,,ڔ,,*,*,*,D,e,e,0/2,*,-1"
-#define NJD_SET_DIGIT_ZERO "Z"
+#define NJD_SET_DIGIT_ZERO1 "Z"
+#define NJD_SET_DIGIT_ZERO2 "O"
 #define NJD_SET_DIGIT_ZERO_BEFORE_DP "["
 #define NJD_SET_DIGIT_ZERO_AFTER_DP "["
 #define NJD_SET_DIGIT_TWO ""
@@ -79,6 +82,15 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_NICHIKAN ""
 #define NJD_SET_DIGIT_ONE ""
 #define NJD_SET_DIGIT_TSUITACHI ",,\,*,*,*,*,,cC^`,cC^`,4/4,*"
+#define NJD_SET_DIGIT_FOUR "l"
+#define NJD_SET_DIGIT_TEN "\"
+#define NJD_SET_DIGIT_JUYOKKA "\l,,\,*,*,*,*,\l,WEbJ,W[bJ,1/5,*"
+#define NJD_SET_DIGIT_JUYOKKAKAN "\l,,\,*,*,*,*,\l,WEbJJ,W[bJJ,5/7,*"
+#define NJD_SET_DIGIT_NIJU "\,,\,*,*,*,*,\,jWE,jW[,1/3,*"
+#define NJD_SET_DITIT_YOKKA "l,,\,*,*,*,*,l,bJ,bJ,0/3,*,0"
+#define NJD_SET_DIGIT_YOKKAKAN "l,,\,*,*,*,*,l,bJJ,bJJ,3/5,*,0"
+#define NJD_SET_DITIT_HATSUKA "\,,\,*,*,*,*,\,ncJ,ncJ,0/3,*"
+#define NJD_SET_DIGIT_HATSUKAKAN "\,,\,*,*,*,*,\,ncJJ,ncJJ,3/5,*"
 
 static const char *njd_set_digit_rule_numeral_list1[] = {
    "", "0", "Z",
@@ -110,7 +122,7 @@ static const char *njd_set_digit_rule_numeral_list1[] = {
    "͂", "8", "",
    "イ", "9", "",
    "Z", "0", "Z",
-   "O", "0", "Z",
+   "O", "0", "O",
    "", "1", "",
    "", "2", "",
    "", "2", "",
@@ -135,20 +147,20 @@ static const char *njd_set_digit_rule_numeral_list3[] = {
    ",,,*,*,*,*,,},},1/2,*",
    ",,,*,*,*,*,,IN,IN,1/2,*",
    ",,,*,*,*,*,,`E,`[,1/2,C3",
-   ",,,*,*,*,*,,PC,PC,1/2,*",
+   ",,,*,*,*,*,,PC,P[,1/2,*",
    ",,,*,*,*,*,,KC,KC,1/2,*",
-   "ї\,,,*,*,*,*,ї\,W,W,1/1,*", /* No character in EUC-JP */
-   ",,,*,*,*,*,,WE,WE,1/2,*",
+   "ї\,,,*,*,*,*,ї\,W,W,1/1,*", /* none in this charcode */
+   ",,,*,*,*,*,,WE,W[,1/2,*",
    "a,,,*,*,*,*,a,RE,RE,1/2,*",
    ",,,*,*,*,*,,J,J,1/2,*",
-   ",,,*,*,*,*,,ZC,ZC,1/2,*",
+   ",,,*,*,*,*,,ZC,Z[,1/2,*",
    ",,,*,*,*,*,,TC,TC,1/2,*",
    ",,,*,*,*,*,,SN,SN,1/2,*",
    "P͍,,,*,*,*,*,P͍,SEKV,SEKV,1/4,*",
-   "m_,,,*,*,*,*,m_,A\EM,A\EM,2/4,*",
+   "m_,,,*,*,*,*,m_,A\EM,A\[M,2/4,*",
    "ߗR,,,*,*,*,*,ߗR,i^,i^,1/3,*",
    "svc,,,*,*,*,*,svc,tJVM,tJVM,2/4,*",
-   "ʑ吔,,,*,*,*,*,ʑ吔,E^CXE,[^CXE,6/7,*",
+   "ʑ吔,,,*,*,*,*,ʑ吔,E^CXE,[^CX[,6/7,*",
    NULL
 };
 
@@ -158,7 +170,9 @@ static const char *njd_set_digit_rule_numeral_list4[] = {
 };
 
 static const char *njd_set_digit_rule_numeral_list5[] = {
-   "\", "S", "", "", "", "", "", "", "ї\", "", "a", "", "", "", "",
+   "\", "S", "", "", "", "", "", "",
+   "ї\", /* none in this charcode */
+   "", "a", "", "", "", "",
    "P͍", "m_", "ߗR", "svc", "ʑ吔",
    NULL
 };
@@ -211,9 +225,9 @@ static const char *njd_set_digit_rule_conv_table1b[] = {
 
 static const char *njd_set_digit_rule_numerative_class1c1[] = {
    /* from paper */
-   "", "", "l",
+   "l",
    /* from dictionary */
-   "", "", "l", "lO", "lg",
+   "l", "lO", "lg",
    NULL
 };
 
@@ -232,6 +246,8 @@ static const char *njd_set_digit_rule_numerative_class1c2[] = {
 };
 
 static const char *njd_set_digit_rule_conv_table1c2[] = {
+   "l", "", "0", "1",
+   "", "V`", "1", "2",
    "", "N", "0", "1",
    NULL, NULL, NULL, NULL
 };
@@ -290,9 +306,9 @@ static const char *njd_set_digit_rule_numerative_class1g[] = {
    "", "", "", "", "", "і", "", "", "", "", "@", "C", "G", "R",
    "q", "r", "", "", "", "", "", "", "d", "", "", "", "", "", "v",
    "", "P^", "Z", "`", "s", "", "g", "", "", "", "", "", "N", "",
-   "҂", "؂", "g", "h", "s", "t", "", "", "", "", "", "C", "C", "M", "U",
+   "҂", "؂", "g", "h", "s", "t", "", "", "", "", "", "C", "D", "M", "U",
    "[", "i", "", "", "", "", "", "", "", "", "", "", "", "", "",
-   "@", "{",
+   "@", "{", "g",
    NULL
 };
 
@@ -319,6 +335,7 @@ static const char *njd_set_digit_rule_numerative_class1h[] = {
    "܂", "Ƃ", "Ƃ", "Ƃ", "Ƃ", "", "", "", "", "", "", "",
    "", "M", "", "", "", "", "", "͂", "", "H", "X", "]", "_", "l", "",
    "", "", "", "", "n", "", "", "", "", "", "", "Δn", "I",
+   "Ԏ",
    NULL
 };
 
@@ -369,7 +386,7 @@ static const char *njd_set_digit_rule_numerative_class1k[] = {
    "", "", "p[Zg", "p[~", "pXJ", "pbN", "pbg", "s[s[G",
    "sR", "y[W", "", "yA", "yZ^", "y\", "yj[", "yjq", "yX", "|Cg",
    "U", "j", "", "", "", "L", "L[g", "Z`[g",
-   "[g",
+   "[g", "i",
    NULL
 };
 
@@ -403,7 +420,7 @@ static const char *njd_set_digit_rule_conv_table2b[] = {
 
 static const char *njd_set_digit_rule_numerative_class2c[] = {
    /* from paper */
-   "{", "C", "[", "U", "",
+   "{", "C", "D", "[", "U", "",
    /* from dictionary */
    "{", "t", "j", "",
    NULL
@@ -423,7 +440,7 @@ static const char *njd_set_digit_rule_conv_table2c[] = {
 };
 
 static const char *njd_set_digit_rule_numerative_class2d[] = {
-/* from paper */
+   /* from paper */
    /* "H", "c", *//* modified */
    NULL
 };
@@ -582,17 +599,18 @@ static const char *njd_set_digit_rule_conv_table4[] = {
 
 static const char *njd_set_digit_rule_conv_table5[] = {
    "", ",,\,*,*,*,*,,C`j`,C`j`,4/4,*",
-   "", ",,\,*,*,*,*,,tcJ,tcJ,3/3,*",
-   "O", "O,,\,*,*,*,*,O,~bJ,~bJ,3/3,*",
-   "l", "l,,\,*,*,*,*,l,bJ,bJ,3/3,*",
-   "", "ܓ,,\,*,*,*,*,ܓ,CcJ,CcJ,3/3,*",
-   "Z", "Z,,\,*,*,*,*,Z,CJ,CJ,3/3,*",
-   "", ",,\,*,*,*,*,,imJ,imJ,3/3,*",
-   "", ",,\,*,*,*,*,,EJ,EJ,3/3,*",
-   "", ",,\,*,*,*,*,,RRmJ,RRmJ,4/4,*",
-   "\", "\,,\,*,*,*,*,\,gEJ,g[J,3/3,*",
+   "", ",,\,*,*,*,*,,tcJ,tcJ,0/3,*",
+   "O", "O,,\,*,*,*,*,O,~bJ,~bJ,0/3,*",
+   "l", "l,,\,*,*,*,*,l,bJ,bJ,0/3,*",
+   "", "ܓ,,\,*,*,*,*,ܓ,CcJ,CcJ,0/3,*",
+   "Z", "Z,,\,*,*,*,*,Z,CJ,CJ,0/3,*",
+   "", ",,\,*,*,*,*,,imJ,imJ,0/3,*",
+   "", ",,\,*,*,*,*,,EJ,[J,0/3,*",
+   "", ",,\,*,*,*,*,,RRmJ,RRmJ,0/4,*",
+   "\", "\,,\,*,*,*,*,\,gEJ,g[J,0/3,*",
    NULL, NULL
 };
+
 static const char *njd_set_digit_rule_conv_table6[] = {
    "", ",,\,*,*,*,*,,C`j`J,C`j`J,4/6,*",
    "", ",,\,*,*,*,*,,tcJJ,tcJJ,3/5,*",
@@ -601,7 +619,7 @@ static const char *njd_set_digit_rule_conv_table6[] = {
    "", "ܓ,,\,*,*,*,*,ܓ,CcJJ,CcJJ,3/5,*",
    "Z", "Z,,\,*,*,*,*,Z,CJJ,CJJ,3/5,*",
    "", ",,\,*,*,*,*,,imJJ,imJJ,3/5,*",
-   "", ",,\,*,*,*,*,,EJJ,EJJ,3/5,*",
+   "", ",,\,*,*,*,*,,EJJ,[JJ,3/5,*",
    "", ",,\,*,*,*,*,,RRmJJ,RRmJJ,4/6,*",
    "\", "\,,\,*,*,*,*,\,gEJJ,g[JJ,3/5,*",
    NULL, NULL
