@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2013  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2016  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -117,6 +117,10 @@ static int detect_byte(const char *str)
 
 void njd_set_long_vowel(NJD * njd)
 {
+#if 1
+   /* long vowel estimator is deprecated */
+   return;
+#else
    int i, j;
    NJDNode *node;
    const char *str;
@@ -149,6 +153,7 @@ void njd_set_long_vowel(NJD * njd)
       /* finish */
       NJDNode_set_pron(node, buff);
    }
+#endif
 }
 
 NJD_SET_LONG_VOWEL_C_END;
