@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2013  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2016  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -136,7 +136,6 @@ static const char *njd_set_pronunciation_list[] = {
    "\xe3\x83\x87\xe3\x83\xa7", "\xe3\x83\x87\xe3\x83\xa7", "1",
    "\xe3\x83\x87\xe3\x83\xa5", "\xe3\x83\x87\xe3\x83\xa5", "1",
    "\xe3\x83\x87\xe3\x83\xa3", "\xe3\x83\x87\xe3\x83\xa3", "1",
-   "\xe3\x83\x87\xe3\x82\xa7", "\xe3\x83\x87\xe3\x82\xa7", "1",
    "\xe3\x83\x87\xe3\x82\xa3", "\xe3\x83\x87\xe3\x82\xa3", "1",
    "\xe3\x83\x87", "\xe3\x83\x87", "1",
    "\xe3\x83\x86\xe3\x83\xa7", "\xe3\x83\x86\xe3\x83\xa7", "1",
@@ -211,6 +210,14 @@ static const char *njd_set_pronunciation_list[] = {
    "\xe3\x82\xa3", "\xe3\x82\xa3", "1",
    "\xe3\x82\xa2", "\xe3\x82\xa2", "1",
    "\xe3\x82\xa1", "\xe3\x82\xa1", "1",
+   "\xe3\x82\x94\xe3\x82\x87", "\xe3\x83\xb4\xe3\x83\xa7", "1",
+   "\xe3\x82\x94\xe3\x82\x85", "\xe3\x83\xb4\xe3\x83\xa5", "1",
+   "\xe3\x82\x94\xe3\x82\x83", "\xe3\x83\xb4\xe3\x83\xa3", "1",
+   "\xe3\x82\x94\xe3\x81\x89", "\xe3\x83\xb4\xe3\x82\xa9", "1",
+   "\xe3\x82\x94\xe3\x81\x87", "\xe3\x83\xb4\xe3\x82\xa7", "1",
+   "\xe3\x82\x94\xe3\x81\x83", "\xe3\x83\xb4\xe3\x82\xa3", "1",
+   "\xe3\x82\x94\xe3\x81\x81", "\xe3\x83\xb4\xe3\x82\xa1", "1",
+   "\xe3\x82\x94", "\xe3\x83\xb4", "1",
    "\xe3\x82\x93", "\xe3\x83\xb3", "1",
    "\xe3\x82\x92", "\xe3\x83\xb2", "1",
    "\xe3\x82\x91", "\xe3\x83\xb1", "1",
@@ -287,7 +294,6 @@ static const char *njd_set_pronunciation_list[] = {
    "\xe3\x81\xa7\xe3\x82\x87", "\xe3\x83\x87\xe3\x83\xa7", "1",
    "\xe3\x81\xa7\xe3\x82\x85", "\xe3\x83\x87\xe3\x83\xa5", "1",
    "\xe3\x81\xa7\xe3\x82\x83", "\xe3\x83\x87\xe3\x83\xa3", "1",
-   "\xe3\x81\xa7\xe3\x81\x87", "\xe3\x83\x87\xe3\x82\xa7", "1",
    "\xe3\x81\xa7\xe3\x81\x83", "\xe3\x83\x87\xe3\x82\xa3", "1",
    "\xe3\x81\xa7", "\xe3\x83\x87", "1",
    "\xe3\x81\xa6\xe3\x82\x87", "\xe3\x83\x86\xe3\x83\xa7", "1",
@@ -387,7 +393,7 @@ static const char *njd_set_pronunciation_list[] = {
    "\xef\xbd\x84", "\xe3\x83\x87\xe3\x82\xa3\xe3\x83\xbc", "2",
    "\xef\xbd\x83", "\xe3\x82\xb7\xe3\x83\xbc", "2",
    "\xef\xbd\x82", "\xe3\x83\x93\xe3\x83\xbc", "2",
-   "\xef\xbd\x81", "\xe3\x82\xa8\xe3\x82\xa4", "2",
+   "\xef\xbd\x81", "\xe3\x82\xa8\xe3\x83\xbc", "2",
    "\xef\xbc\xba", "\xe3\x82\xba\xe3\x82\xa3\xe3\x83\xbc", "2",
    "\xef\xbc\xb9", "\xe3\x83\xaf\xe3\x82\xa4", "2",
    "\xef\xbc\xb8", "\xe3\x82\xa8\xe3\x83\x83\xe3\x82\xaf\xe3\x82\xb9", "4",
@@ -413,7 +419,7 @@ static const char *njd_set_pronunciation_list[] = {
    "\xef\xbc\xa4", "\xe3\x83\x87\xe3\x82\xa3\xe3\x83\xbc", "2",
    "\xef\xbc\xa3", "\xe3\x82\xb7\xe3\x83\xbc", "2",
    "\xef\xbc\xa2", "\xe3\x83\x93\xe3\x83\xbc", "2",
-   "\xef\xbc\xa1", "\xe3\x82\xa8\xe3\x82\xa4", "2",
+   "\xef\xbc\xa1", "\xe3\x82\xa8\xe3\x83\xbc", "2",
    "\xe3\x83\xbc", "\xe3\x83\xbc", "1",
    NULL, NULL, NULL
 };
@@ -422,97 +428,12 @@ static const char *njd_set_pronunciation_list[] = {
 #define NJD_SET_PRONUNCIATION_KAZU "\xe6\x95\xb0"
 
 static const char *njd_set_pronunciation_symbol_list[] = {
-   "\xe3\x80\x80", "\xe3\x80\x81",
-   "\xe3\x80\x81", "\xe3\x80\x81",
-   "\xe3\x80\x82", "\xe3\x80\x81",
-   "\xef\xbc\x8c", "\xe3\x80\x81",
-   "\xef\xbc\x8e", "\xe3\x80\x81",
-   "\xe3\x83\xbb", "\xe3\x80\x81",
-   "\xef\xbc\x9a", "\xe3\x80\x81",
-   "\xef\xbc\x9b", "\xe3\x80\x81",
    "\xef\xbc\x9f", "\xef\xbc\x9f",
-   "\xef\xbc\x81", "\xe3\x80\x81",
-   "\xe3\x82\x9b", "\xe3\x80\x81",
-   "\xe3\x82\x9c", "\xe3\x80\x81",
-   "\xc2\xb4", "\xe3\x80\x81",
-   "\xef\xbd\x80", "\xe3\x80\x81",
-   "\xc2\xa8", "\xe3\x80\x81",
-   "\xef\xbc\xbe", "\xe3\x80\x81",
-   "\xef\xbf\xa3", "\xe3\x80\x81",
-   "\xef\xbc\xbf", "\xe3\x80\x81",
-   "\xe3\x83\xbd", "\xe3\x80\x81",
-   "\xe3\x83\xbe", "\xe3\x80\x81",
-   "\xe3\x82\x9d", "\xe3\x80\x81",
-   "\xe3\x82\x9e", "\xe3\x80\x81",
-   "\xe3\x80\x83", "\xe3\x80\x81",
-   "\xe4\xbb\x9d", "\xe3\x80\x81",
-   "\xe3\x80\x85", "\xe3\x80\x81",
-   "\xe3\x80\x85\xe3\x80\x85", "\xe3\x80\x81",
-   "\xe3\x80\x86", "\xe3\x80\x81",
-   "\xe3\x80\x87", "\xe3\x80\x81",
-   "\xe2\x80\x95", "\xe3\x80\x81",
-   "\xe2\x80\x95\xe2\x80\x95", "\xe3\x80\x81",
-   "\xe2\x80\x90", "\xe3\x80\x81",
-   "\xef\xbc\x8f", "\xe3\x80\x81",
-   "\xef\xbc\xbc", "\xe3\x80\x81",
-   "\xe3\x80\x9c", "\xe3\x80\x81",
-   "\xe2\x80\x96", "\xe3\x80\x81",
-   "\xef\xbd\x9c", "\xe3\x80\x81",
-   "\xe2\x80\xa6", "\xe3\x80\x81",
-   "\xe2\x80\xa5", "\xe3\x80\x81",
-   "\xe2\x80\x98", "\xe3\x80\x81",
-   "\xe2\x80\x99", "\xe3\x80\x81",
-   "\xe2\x80\x9c", "\xe3\x80\x81",
-   "\xe2\x80\x9d", "\xe3\x80\x81",
-   "\xef\xbc\x88", "\xe3\x80\x81",
-   "\xef\xbc\x89", "\xe3\x80\x81",
-   "\xe3\x80\x94", "\xe3\x80\x81",
-   "\xe3\x80\x95", "\xe3\x80\x81",
-   "\xef\xbc\xbb", "\xe3\x80\x81",
-   "\xef\xbc\xbd", "\xe3\x80\x81",
-   "\xef\xbd\x9b", "\xe3\x80\x81",
-   "\xef\xbd\x9d", "\xe3\x80\x81",
-   "\xe3\x80\x88", "\xe3\x80\x81",
-   "\xe3\x80\x89", "\xe3\x80\x81",
-   "\xe3\x80\x8a", "\xe3\x80\x81",
-   "\xe3\x80\x8b", "\xe3\x80\x81",
-   "\xe3\x80\x8c", "\xe3\x80\x81",
-   "\xe3\x80\x8d", "\xe3\x80\x81",
-   "\xe3\x80\x8e", "\xe3\x80\x81",
-   "\xe3\x80\x8f", "\xe3\x80\x81",
-   "\xe3\x80\x90", "\xe3\x80\x81",
-   "\xe3\x80\x91", "\xe3\x80\x81",
-   "\xe2\x88\x92\xe2\x88\x92", "\xe3\x80\x81",
-   "\xef\xbc\x9d", "\xe3\x80\x81",
-   "\xef\xbc\x9c", "\xe3\x80\x81",
-   "\xef\xbc\x9e", "\xe3\x80\x81",
-   "\xe2\x80\xb2", "\xe3\x80\x81",
-   "\xef\xbc\x8a", "\xe3\x80\x81",
-   "\xe2\x98\x86", "\xe3\x80\x81",
-   "\xe2\x98\x85", "\xe3\x80\x81",
-   "\xe2\x97\x8b", "\xe3\x80\x81",
-   "\xe2\x97\x8f", "\xe3\x80\x81",
-   "\xe2\x97\x8e", "\xe3\x80\x81",
-   "\xe2\x97\x87", "\xe3\x80\x81",
-   "\xe2\x97\x86", "\xe3\x80\x81",
-   "\xe2\x96\xa1", "\xe3\x80\x81",
-   "\xe2\x96\xa0", "\xe3\x80\x81",
-   "\xe2\x96\xb3", "\xe3\x80\x81",
-   "\xe2\x96\xb2", "\xe3\x80\x81",
-   "\xe2\x96\xbd", "\xe3\x80\x81",
-   "\xe2\x96\xbc", "\xe3\x80\x81",
-   "\xe2\x80\xbb", "\xe3\x80\x81",
-   "\xe2\x86\x92", "\xe3\x80\x81",
-   "\xe2\x86\x90", "\xe3\x80\x81",
-   "\xe2\x86\x91", "\xe3\x80\x81",
-   "\xe2\x86\x93", "\xe3\x80\x81",
-   "\xe3\x80\x93", "\xe3\x80\x81",
-   "\xe2\x94\x80", "\xe3\x80\x81",
-   "\xe2\x94\x80\xe2\x94\x80", "\xe3\x80\x81",
-   "\xe2\x88\x92", "\xe3\x80\x81",
    NULL, NULL
 };
 
+#define NJD_SET_PRONUNCIATION_FILLER "\xe3\x83\x95\xe3\x82\xa3\xe3\x83\xa9\xe3\x83\xbc"
+
 #define NJD_SET_PRONUNCIATION_U        "\xe3\x82\xa6"
 #define NJD_SET_PRONUNCIATION_DOUSHI   "\xe5\x8b\x95\xe8\xa9\x9e"
 #define NJD_SET_PRONUNCIATION_JODOUSHI "\xe5\x8a\xa9\xe5\x8b\x95\xe8\xa9\x9e"
@@ -524,6 +445,8 @@ static const char *njd_set_pronunciation_symbol_list[] = {
 #define NJD_SET_PRONUNCIATION_DESU_PRON "\xe3\x83\x87\xe3\x82\xb9"
 #define NJD_SET_PRONUNCIATION_MASU_PRON "\xe3\x83\x9e\xe3\x82\xb9"
 
+#define NJD_SET_PRONUNCIATION_TOUTEN "\xe3\x80\x81"
+
 NJD_SET_PRONUNCIATION_RULE_H_END;
 
 #endif                          /* !NJD_SET_PRONUNCIATION_RULE_H */
