@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2013  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2016  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -53,42 +53,52 @@ NJD_SET_UNVOICED_VOWEL_RULE_H_START;
 
 /*
   無声子音: k ky s sh t ty ch ts h f hy p py
-  Rule 1 助動詞の「です」と「ます」の「す」が無声化 (辞書修正済)
-  Rule 2 続けて無声化しない
-  Rule 3 アクセント核で無声化しない
-  Rule 4 無声子音(k ky s sh t ty ch ts h f hy p py)に囲まれた「i」と「u」が無声化
+  Rule 0 フィラーは無声化しない
+  Rule 1 助動詞の「です」と「ます」の「す」が無声化
+  Rule 2 動詞，助動詞，助詞の「し」は無声化しやすい
+  Rule 3 続けて無声化しない
+  Rule 4 アクセント核で無声化しない
+  Rule 5 無声子音(k ky s sh t ty ch ts h f hy p py)に囲まれた「i」と「u」が無声化
          例外：s->s, s->sh, f->f, f->h, f->hy, h->f, h->h, h->hy
 */
 
-#define NJD_SET_UNVOICED_VOWEL_QUOTATION "’"
-#define NJD_SET_UNVOICED_VOWEL_QUESTION "？"
-#define NJD_SET_UNVOICED_VOWEL_TOUTEN "、"
-
+#define NJD_SET_UNVOICED_VOWEL_FILLER "フィラー"
+#define NJD_SET_UNVOICED_VOWEL_DOUSHI "動詞"
 #define NJD_SET_UNVOICED_VOWEL_JODOUSHI "助動詞"
+#define NJD_SET_UNVOICED_VOWEL_JOSHI "助詞"
+#define NJD_SET_UNVOICED_VOWEL_KANDOUSHI "感動詞"
+#define NJD_SET_UNVOICED_VOWEL_TOUTEN "、"
+#define NJD_SET_UNVOICED_VOWEL_QUESTION "？"
+#define NJD_SET_UNVOICED_VOWEL_QUOTATION "’"
+#define NJD_SET_UNVOICED_VOWEL_SHI "シ"
+#define NJD_SET_UNVOICED_VOWEL_MA "マ"
+#define NJD_SET_UNVOICED_VOWEL_DE "デ"
+#define NJD_SET_UNVOICED_VOWEL_CHOUON "ー"
+#define NJD_SET_UNVOICED_VOWEL_SU "ス"
 
 static const char *njd_set_unvoiced_vowel_candidate_list1[] = {
-   "スィ",                      /* s i */
-   "ス",                        /* s u */
+   "スィ",                    /* s i */
+   "ス",                       /* s u */
    NULL
 };
 
 static const char *njd_set_unvoiced_vowel_next_mora_list1[] = {
-   "カ",                        /* k ky */
+   "カ",                       /* k ky */
    "キ",
    "ク",
    "ケ",
    "コ",
-   "タ",                        /* t ty ch ts */
+   "タ",                       /* t ty ch ts */
    "チ",
    "ツ",
    "テ",
    "ト",
-   "ハ",                        /* h f hy */
+   "ハ",                       /* h f hy */
    "ヒ",
    "フ",
    "ヘ",
    "ホ",
-   "パ",                        /* p py */
+   "パ",                       /* p py */
    "ピ",
    "プ",
    "ペ",
@@ -97,29 +107,29 @@ static const char *njd_set_unvoiced_vowel_next_mora_list1[] = {
 };
 
 static const char *njd_set_unvoiced_vowel_candidate_list2[] = {
-   "フィ",                      /* f i */
-   "ヒ",                        /* h i */
-   "フ",                        /* f u */
+   "フィ",                    /* f i */
+   "ヒ",                       /* h i */
+   "フ",                       /* f u */
    NULL
 };
 
 static const char *njd_set_unvoiced_vowel_next_mora_list2[] = {
-   "カ",                        /* k ky */
+   "カ",                       /* k ky */
    "キ",
    "ク",
    "ケ",
    "コ",
-   "サ",                        /* s sh */
+   "サ",                       /* s sh */
    "シ",
    "ス",
    "セ",
    "ソ",
-   "タ",                        /* t ty ch ts */
+   "タ",                       /* t ty ch ts */
    "チ",
    "ツ",
    "テ",
    "ト",
-   "パ",                        /* p py */
+   "パ",                       /* p py */
    "ピ",
    "プ",
    "ペ",
@@ -128,47 +138,47 @@ static const char *njd_set_unvoiced_vowel_next_mora_list2[] = {
 };
 
 static const char *njd_set_unvoiced_vowel_candidate_list3[] = {
-   "キュ",                      /* ky u */
-   "シュ",                      /* sh u */
-   "チュ",                      /* ch u */
-   "ツィ",                      /* ts i */
-   "ヒュ",                      /* hy u */
-   "ピュ",                      /* py u */
-   "テュ",                      /* ty u */
-   "トゥ",                      /* t u */
-   "ティ",                      /* t i */
-   "キ",                        /* k i */
-   "ク",                        /* k u */
-   "シ",                        /* sh i */
-   "チ",                        /* ch i */
-   "ツ",                        /* ts u */
-   "ピ",                        /* p i */
-   "プ",                        /* p u */
+   "キュ",                    /* ky u */
+   "シュ",                    /* sh u */
+   "チュ",                    /* ch u */
+   "ツィ",                    /* ts i */
+   "ヒュ",                    /* hy u */
+   "ピュ",                    /* py u */
+   "テュ",                    /* ty u */
+   "トゥ",                    /* t u */
+   "ティ",                    /* t i */
+   "キ",                       /* k i */
+   "ク",                       /* k u */
+   "シ",                       /* sh i */
+   "チ",                       /* ch i */
+   "ツ",                       /* ts u */
+   "ピ",                       /* p i */
+   "プ",                       /* p u */
    NULL
 };
 
 static const char *njd_set_unvoiced_vowel_next_mora_list3[] = {
-   "カ",                        /* k ky */
+   "カ",                       /* k ky */
    "キ",
    "ク",
    "ケ",
    "コ",
-   "サ",                        /* s sh */
+   "サ",                       /* s sh */
    "シ",
    "ス",
    "セ",
    "ソ",
-   "タ",                        /* t ty ch ts */
+   "タ",                       /* t ty ch ts */
    "チ",
    "ツ",
    "テ",
    "ト",
-   "ハ",                        /* h f hy */
+   "ハ",                       /* h f hy */
    "ヒ",
    "フ",
    "ヘ",
    "ホ",
-   "パ",                        /* p py */
+   "パ",                       /* p py */
    "ピ",
    "プ",
    "ペ",
@@ -261,7 +271,6 @@ static const char *njd_set_unvoiced_vowel_mora_list[] = {
    "デョ",
    "デュ",
    "デャ",
-   "デェ",
    "ディ",
    "デ",
    "テョ",
